package com.ruoyi.asset.mapper;

import java.util.List;
import com.ruoyi.asset.domain.TbLocation;

/**
 * 所属位置Mapper接口
 * 
 * @author 原动力
 * @date 2023-05-15
 */
public interface TbLocationMapper 
{
    /**
     * 查询所属位置
     * 
     * @param id 所属位置主键
     * @return 所属位置
     */
    public TbLocation selectTbLocationById(Long id);

    /**
     * 查询所属位置列表
     * 
     * @param tbLocation 所属位置
     * @return 所属位置集合
     */
    public List<TbLocation> selectTbLocationList(TbLocation tbLocation);

    /**
     * 新增所属位置
     * 
     * @param tbLocation 所属位置
     * @return 结果
     */
    public int insertTbLocation(TbLocation tbLocation);

    /**
     * 修改所属位置
     * 
     * @param tbLocation 所属位置
     * @return 结果
     */
    public int updateTbLocation(TbLocation tbLocation);

    /**
     * 删除所属位置
     * 
     * @param id 所属位置主键
     * @return 结果
     */
    public int deleteTbLocationById(Long id);

    /**
     * 批量删除所属位置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbLocationByIds(Long[] ids);
}
